# ApiKeyWithEnvDto


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**env_id** | **str** |  | 
**key** | **str** |  | 
**viewed** | **bool** |  | 
**updated_at** | **str** |  | 
**environment** | [**EnvironmentDto**](EnvironmentDto.md) |  | 

## Example

```python
from openapi_client.models.api_key_with_env_dto import ApiKeyWithEnvDto

# TODO update the JSON string below
json = "{}"
# create an instance of ApiKeyWithEnvDto from a JSON string
api_key_with_env_dto_instance = ApiKeyWithEnvDto.from_json(json)
# print the JSON string representation of the object
print ApiKeyWithEnvDto.to_json()

# convert the object into a dict
api_key_with_env_dto_dict = api_key_with_env_dto_instance.to_dict()
# create an instance of ApiKeyWithEnvDto from a dict
api_key_with_env_dto_form_dict = api_key_with_env_dto.from_dict(api_key_with_env_dto_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


